==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/managednetwork/kotlin/inputs/ResourceIdArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetwork.kotlin.inputs

import com.pulumi.azurenative.managednetwork.inputs.ResourceIdArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Generic pointer to a resource
 * @property id Resource Id
 */
public data class ResourceIdArgs(
    public val id: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.managednetwork.inputs.ResourceIdArgs> {
    override fun toJava(): com.pulumi.azurenative.managednetwork.inputs.ResourceIdArgs =
        com.pulumi.azurenative.managednetwork.inputs.ResourceIdArgs.builder()
            .id(id?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResourceIdArgs].
 */
@PulumiTagMarker
public class ResourceIdArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    /**
     * @param value Resource Id
     */
    @JvmName("neaulvvrfatfitxc")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Resource Id
     */
    @JvmName("tsutmrrewoyuuytf")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    internal fun build(): ResourceIdArgs = ResourceIdArgs(
        id = id,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/managednetwork/kotlin/inputs/ResourceIdArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.managednetwork.kotlin.inputs

import com.pulumi.azurenative.managednetwork.inputs.ResourceIdArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Generic pointer to a resource
 * @property id Resource Id
 */
public data class ResourceIdArgs(
    public val id: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.managednetwork.inputs.ResourceIdArgs> {
    override fun toJava(): com.pulumi.azurenative.managednetwork.inputs.ResourceIdArgs =
        com.pulumi.azurenative.managednetwork.inputs.ResourceIdArgs.builder()
            .id(id?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ResourceIdArgs].
 */
@PulumiTagMarker
public class ResourceIdArgsBuilder internal constructor() {
    private var id: Output<String>? = null

    /**
     * @param value Resource Id
     */
    @JvmName("rmpcelpclouidtxf")
    public suspend fun id(`value`: Output<String>) {
        this.id = value
    }

    /**
     * @param value Resource Id
     */
    @JvmName("obshuacoboeshwft")
    public suspend fun id(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.id = mapped
    }

    internal fun build(): ResourceIdArgs = ResourceIdArgs(
        id = id,
    )
}
